<?php

namespace Roka\NotificationBBCodes\BbCode;

class Notification
{
    public static $Codes = ['error', 'information', 'success', 'warning'];

    public static function renderNotificationBbCode($type, array $codeOptions)
    {
        $tagChildren = $codeOptions['tagChildren'];
        $tagOption = explode (',', $codeOptions['tagOptions']) ;
        $tag = $codeOptions['tag'];
        $options = $codeOptions['options'];
        $renderer = $codeOptions['renderer'];

        // Get content
        $content = $renderer->renderSubTree($tagChildren, $options);

        switch ($type) {
            case 'error':
            {
                if ($tagOption > 0) {
                    $title = $tagOption[0];
                    $icon = 'bullhorn';
                    $class = 'error';
                }
            }
                break;
            case 'information':
            {
                if ($tagOption > 0) {
                    $title = $tagOption[0];
                    $icon = 'info';
                    $class = 'information';
                }

            }
                break;
            case 'success':
            {
                if ($tagOption > 0) {
                    $title = $tagOption[0];
                    $icon = 'check';
                    $class = 'success';
                }
            }
                break;
            case 'warning':
            {
                if ($tagOption > 0) {
                    $title = $tagOption[0];
                    $icon = 'exclamation';
                    $class = 'warning';
                }

            }
                break;
        }

        if ($renderer instanceof \XF\BbCode\Renderer\EmailHtml)
        {
            $content = false;
        }

        return $renderer->getTemplater()->renderTemplate('public:notification_bb_codes_template', [
            'content' => $content ? new \XF\PreEscaped($content) : false,
            'icon' => $icon,
            'class' => $class,
            'title' => $title ? new \XF\PreEscaped($title) : ''
        ]);
    }


    //Error Box
    public static function getError($tagChildren, $tagOption, $tag, array $options, \XF\BbCode\Renderer\AbstractRenderer $renderer)
    {
        return self::renderNotificationBbCode('error', [
            'tagChildren' => $tagChildren,
            'tagOptions' => $tagOption,
            'tag' => $tag,
            'options' => $options,
            'renderer' => $renderer
        ]);
    }


    public static function getSuccess($tagChildren, $tagOption, $tag, array $options, \XF\BbCode\Renderer\AbstractRenderer $renderer)
    {
        return self::renderNotificationBbCode('success', [
            'tagChildren' => $tagChildren,
            'tagOptions' => $tagOption,
            'tag' => $tag,
            'options' => $options,
            'renderer' => $renderer
        ]);
    }

    public static function getInformation($tagChildren, $tagOption, $tag, array $options, \XF\BbCode\Renderer\AbstractRenderer $renderer)
    {
        return self::renderNotificationBbCode('information', [
            'tagChildren' => $tagChildren,
            'tagOptions' => $tagOption,
            'tag' => $tag,
            'options' => $options,
            'renderer' => $renderer
        ]);
    }

    public static function getWarning($tagChildren, $tagOption, $tag, array $options, \XF\BbCode\Renderer\AbstractRenderer $renderer)
    {
        return self::renderNotificationBbCode('warning', [
            'tagChildren' => $tagChildren,
            'tagOptions' => $tagOption,
            'tag' => $tag,
            'options' => $options,
            'renderer' => $renderer
        ]);
    }

}